@@ -4,30 +4,28 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-gTestfile = 'regress-354145-05.js';
+gTestfile = 'regress-458679-01.js';
 
-var BUGNUMBER = 354145;
-var summary = 'Immutable XML';
-var actual = 'No Crash';
-var expect = 'No Crash';
+var summary = 'GetXMLEntity should not assume FastAppendChar is infallible';
+var BUGNUMBER = 458679;
+var actual = '';
+var expect = '';
 
 printBugNumber(BUGNUMBER);
 START(summary);
 
-var xml = <tag/>;
-var N = 10;
-for (var i = 0; i != N; ++i)
-  xml.appendChild(<{'a'+i}/>);
-
-function prepare()
+try
 {
-  delete xml.*;
-  gc();
-  return "test";
-}
+    var x = "<";
 
-var last = xml.*[N - 1];
-xml.insertChildBefore(last, { toString: prepare });
+    while (x.length < 12000000)
+        x += x;
+
+    <e4x>{x}</e4x>;
+}
+catch(ex)
+{
+}
 
 TEST(1, expect, actual);
 
