@@ -3,36 +3,38 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-gTestfile = '15.7.3.4-2.js';
+gTestfile = '15.7.3.3-2.js';
 
 /**
-   File Name:          15.7.3.4-2.js
-   ECMA Section:       15.7.3.4 Number.NaN
+   File Name:          15.7.3.3-2.js
+   ECMA Section:       15.7.3.3 Number.MIN_VALUE
    Description:        All value properties of the Number object should have
    the attributes [DontEnum, DontDelete, ReadOnly]
 
-   this test checks the DontDelete attribute of Number.NaN
+   this test checks the DontDelete attribute of Number.MIN_VALUE
 
    Author:             christine@netscape.com
    Date:               16 september 1997
 */
 
 
-var SECTION = "15.7.3.4-2";
+var SECTION = "15.7.3.3-2";
 var VERSION = "ECMA_1";
 startTest();
-var TITLE   = "Number.NaN";
+var TITLE   = "Number.MIN_VALUE";
 
 writeHeaderToLog( SECTION + " "+ TITLE );
 
-new TestCase(SECTION,
-	     "delete( Number.NaN ); Number.NaN",      
-	     NaN,       
-	     eval("delete( Number.NaN );Number.NaN" ));
+var MIN_VAL = 5e-324;
 
-new TestCase( SECTION,
-	      "delete( Number.NaN )",  
-	      false, 
-	      eval("delete( Number.NaN )") );
+new TestCase(  SECTION,
+	       "delete( Number.MIN_VALUE )",   
+	       false,
+	       eval("delete( Number.MIN_VALUE )") );
+
+new TestCase(  SECTION,
+	       "delete( Number.MIN_VALUE ); Number.MIN_VALUE",
+	       MIN_VAL,
+	       eval("delete( Number.MIN_VALUE );Number.MIN_VALUE") );
 
 test();
