@@ -3,36 +3,35 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-gTestfile = '12.6.2-7.js';
+gTestfile = '12.6.2-3.js';
 
 /**
-   File Name:          12.6.2-7.js
+   File Name:          12.6.2-3.js
    ECMA Section:       12.6.2 The for Statement
 
-   1. first expression is present.
-   2. second expression is not present
+   1. first expression is not present.
+   2. second expression is present
    3. third expression is present
 
 
    Author:             christine@netscape.com
    Date:               15 september 1997
 */
-var SECTION = "12.6.2-7";
+var SECTION = "12.6.2-3";
 var VERSION = "ECMA_1";
 startTest();
 var TITLE   = "The for statement";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-new TestCase( SECTION, "for statement",  256,     testprogram() );
+new TestCase( SECTION, "for statement",  100,     testprogram() );
 
 test();
 
 function testprogram() {
-  var myVar;
-
-  for ( myVar=2; myVar < 100 ; myVar *= myVar ) {
+  myVar = 0;
 
+  for ( ; myVar < 100 ; myVar++ ) {
     continue;
   }
 
