@@ -3,7 +3,7 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-460116-01.js';
+var gTestfile = 'regress-460116-02.js';
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 460116;
 var summary = 'Condition propagation folding constants';
@@ -23,8 +23,8 @@ function test()
 
   var f;
 
-  f = (function (){if(typeof(false||undef))throw "fail"});
-  expect = 'function (){if(typeof(false||undef)) throw "fail"}';
+  f = (function (){if((false&&foo)===(true||bar));});
+  expect = 'function (){if((false&&foo)===(true||bar));}';
   actual = f + '';
 
   compareSource(expect, actual, summary);
