@@ -3,14 +3,14 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-385393-11.js';
-
+var gTestfile = 'regress-435497-02.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 385393;
-var summary = 'Regression test for bug 385393';
+var BUGNUMBER = 435497;
+var summary = 'Do not assert op2 == JSOP_INITELEM';
 var actual = 'No Crash';
 var expect = 'No Crash';
 
+
 //-----------------------------------------------------------------------------
 test();
 //-----------------------------------------------------------------------------
@@ -20,11 +20,10 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
-
+ 
   try
   {
-    var n = null; 
-    [1 for (x in [])](n.b());
+    eval('(function() { x setter = 0, y; const x; })();');
   }
   catch(ex)
   {
