@@ -3,12 +3,12 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-349023-03.js';
+var gTestfile = 'regress-349012-05.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 349023;
-var summary = 'Bogus JSCLASS_IS_EXTENDED in the generator class';
-var actual = 'No Crash';
-var expect = 'No Crash';
+var BUGNUMBER = 349012;
+var summary = 'generator recursively calling itself via close is an Error';
+var actual = '';
+var expect = '';
 
 
 //-----------------------------------------------------------------------------
@@ -21,10 +21,25 @@ function test()
   printBugNumber(BUGNUMBER);
   printStatus (summary);
 
-  var gen = (function() { yield 3; })();
-  var x = (gen ==gen);
+  var iter;
+  function gen() {
+    iter.close();
+    yield 1;
+  }
 
-  reportCompare(expect, actual, summary);
+  expect = /TypeError.*[aA]lready executing generator/;
+  try
+  {
+    iter = gen();
+    var i = iter.next();
+    print("i="+i);
+  }
+  catch(ex)
+  {
+    print(ex + '');
+    actual = ex + '';
+  }
+  reportMatch(expect, actual, summary);
 
   exitFunc ('test');
 }
