@@ -22,7 +22,7 @@ function test()
   printStatus (summary);
  
   var f = function () { for(; x || (1 for each (y in [])); ) { } };
-  expect = 'function () { for(; x || true; ) { } }';
+  expect = 'function () { for(; x || (1 for each (y in [])); ) { } }';
   actual = f + '';
 
   compareSource(expect, actual, summary);
